@@ -177,6 +177,11 @@ PYTHON_WHEEL_URL = urljoin(
 )
 PYTHON_WHEEL_SHA256 = "2eceb1643c10c5e4a65970baf63bde43b79cbdac7de81dae853ce47ab05197e9"
 
+PYTHON_XS_FIXTURE_CHECKSUMS = {
+    PYTHON_EGG_FILENAME: PYTHON_EGG_SHA256,
+    PYTHON_WHEEL_FILENAME: PYTHON_WHEEL_SHA256,
+}
+
 PYTHON_FIXTURES_PACKAGES = [
     "shelf-reader",
 ]
